@@ -11,6 +11,9 @@
 #include <QObject>
 #include <QQmlEngine>
 
+#include <Plasma/Applet>
+#include <Plasma/Containment>
+
 //
 //  W A R N I N G
 //  -------------
@@ -22,18 +25,16 @@
 // We mean it.
 //
 
-namespace Plasma
-{
-class Applet;
-class Containment;
-}
-
 namespace PlasmaQuick
 {
-// Class used exclusively to generate the Plasmoid.* attached proeprties, which are Applet instances
+// Class used exclusively to generate the Plasmoid.* attached properties, which are Applet instances
 class PlasmoidAttached : public QObject
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(Plasmoid)
+    QML_UNCREATABLE("")
+    QML_ATTACHED(Plasma::Applet)
+    QML_EXTENDED_NAMESPACE(Plasma::Applet) // needed to make enums from Plasma::Applet available
 
 public:
     /*! TODO: When the migration to the new action api is done, remove this enum
@@ -52,10 +53,14 @@ public:
     static Plasma::Applet *qmlAttachedProperties(QObject *object);
 };
 
-// Class used exclusively to generate the Plasmoid.* attached proeprties, which are Applet instances
+// Class used exclusively to generate the Plasmoid.* attached properties, which are Applet instances
 class ContainmentAttached : public QObject
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(Containment)
+    QML_UNCREATABLE("")
+    QML_ATTACHED(Plasma::Containment)
+    QML_EXTENDED_NAMESPACE(Plasma::Containment) // needed to make enums from Plasma::Containment available
 
 public:
     ContainmentAttached(QObject *parent = nullptr);
@@ -67,7 +72,4 @@ public:
 
 }
 
-QML_DECLARE_TYPEINFO(PlasmaQuick::PlasmoidAttached, QML_HAS_ATTACHED_PROPERTIES)
-QML_DECLARE_TYPEINFO(PlasmaQuick::ContainmentAttached, QML_HAS_ATTACHED_PROPERTIES)
-
 #endif
